@@ -14,18 +14,18 @@
 #'  fraction of the observations of the provided data list.
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
+#' my_dl <- data_list(
+#'     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'     list(income, "household_income", "demographics", "continuous"),
+#'     list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'     uid = "unique_id"
+#' )
+#' 
+#' my_dl_subsamples <- subsample_dl(
+#'     my_dl,
+#'     n_subsamples = 20,
+#'     subsample_fraction = 0.85
+#' )
 subsample_dl <- function(dl,
                          n_subsamples,
                          subsample_fraction = NULL,
@@ -85,12 +85,11 @@ subsample_dl <- function(dl,
     return(dl_subsamples)
 }
 
-#' Run SNF clustering pipeline on a list of subsampled data lists.
+#' Run SNF clustering pipeline on a list of subsampled data lists
 #'
 #' @inheritParams batch_snf
 #' @param dl_subsamples A list of subsampled data lists. This object is
 #'  generated by the function `batch_snf_subsamples()`.
-#' @param verbose If TRUE, output progress to console.
 #' @return By default, returns a one-element list: `cluster_solutions`, which
 #'  is itself a list of cluster solution data frames corresponding to each of
 #'  the provided data list subsamples. Setting the parameters
@@ -101,58 +100,67 @@ subsample_dl <- function(dl,
 #'  stability calculations.
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
-#' # 
-#' # batch_subsample_results <- batch_snf_subsamples(
-#' #     my_dl_subsamples,
-#' #     sc,
-#' #     verbose = TRUE
-#' # )
+#' \donttest{
+#' my_dl <- data_list(
+#'     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'     list(income, "household_income", "demographics", "continuous"),
+#'     list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'     uid = "unique_id"
+#' )
+#' 
+#' sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
+#' 
+#' my_dl_subsamples <- subsample_dl(
+#'     my_dl,
+#'     n_subsamples = 20,
+#'     subsample_fraction = 0.85
+#' )
+#' 
+#' batch_subsample_results <- batch_snf_subsamples(
+#'     my_dl_subsamples,
+#'     sc
+#' )
+#' }
 batch_snf_subsamples <- function(dl_subsamples,
                                  sc,
                                  processes = 1,
                                  return_sim_mats = FALSE,
-                                 sim_mats_dir = NULL,
-                                 verbose = TRUE) {
+                                 sim_mats_dir = NULL) {
     # Generate a new solutions data frame for every subsampled data list
-    subsample_sol_dfs <- list()
-    for (s in seq_along(dl_subsamples)) {
-        if (verbose) {
-            cat(
-                "Clustering subsample ", s, "/", length(dl_subsamples),
-                "...\n", sep = ""
-            )
-        }
-        if (!is.null(sim_mats_dir)) {
-            sim_mats_dir_s <- paste0(sim_mats_dir, "/subsample-", s)
-        } else {
-            sim_mats_dir_s <- NULL
-        }
-        invisible(
-            sol_df <- batch_snf(
-                dl = dl_subsamples[[s]],
-                sc = sc,
-                processes = processes,
-                return_sim_mats = return_sim_mats,
-                sim_mats_dir = sim_mats_dir_s
-            )
-        )
-        # Partioning results
-        subsample_sol_dfs[[s]] <- sol_df
+    if (!is.null(sim_mats_dir)) {
+        sim_mats_dir_s <- paste0(sim_mats_dir, "/subsample-", (seq_along(dl_subsamples)))
+    } else {
+        sim_mats_dir_s <- lapply(seq_along(dl_subsamples), function(x) NULL)
     }
+    p <- progressr::progressor(steps = length(dl_subsamples))
+    if (processes == "max") {
+        processes <- max(future::availableCores())
+    }
+    if (processes > 1) {
+        future::plan(future::multisession, workers = processes)
+        apply_fn <- future.apply::future_mapply
+    } else {
+        apply_fn <- mapply
+    }
+    subsample_sol_dfs <- apply_fn(
+        function(x, dir_name, p) {
+            sol_df <- batch_snf(
+                x,
+                sc = sc,
+                processes = 1,
+                return_sim_mats = return_sim_mats,
+                sim_mats_dir = dir_name
+            )
+            p()
+            return(sol_df)
+        },
+        dl_subsamples,
+        sim_mats_dir_s,
+        MoreArgs = list(
+            p = p
+        ),
+        SIMPLIFY = FALSE
+    )
     names(subsample_sol_dfs) <- paste0("subsample_", seq_along(dl_subsamples))
     return(subsample_sol_dfs)
 }
@@ -175,43 +183,44 @@ batch_snf_subsamples <- function(dl_subsamples,
 #'  original cluster solution.
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
-#' # 
-#' # batch_subsample_results <- batch_snf_subsamples(
-#' #     my_dl_subsamples,
-#' #     sc,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # pairwise_aris <- subsample_pairwise_aris(
-#' #     batch_subsample_results
-#' #     verbose = TRUE
-#' # )
-#' #
-#' # # Visualize ARIs 
-#' # ComplexHeatmap::Heatmap(
-#' #     pairwise_aris[[1]],
-#' #     heatmap_legend_param = list(
-#' #         color_bar = "continuous",
-#' #         title = "Inter-Subsample\nARI",
-#' #         at = c(0, 0.5, 1)
-#' #     ),
-#' #     show_column_names = FALSE,
-#' #     show_row_names = FALSE
-#' # )
+#' \donttest{
+#' my_dl <- data_list(
+#'     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'     list(income, "household_income", "demographics", "continuous"),
+#'     list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'     uid = "unique_id"
+#' )
+#' 
+#' sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
+#' 
+#' my_dl_subsamples <- subsample_dl(
+#'     my_dl,
+#'     n_subsamples = 20,
+#'     subsample_fraction = 0.85
+#' )
+#' 
+#' batch_subsample_results <- batch_snf_subsamples(
+#'     my_dl_subsamples,
+#'     sc
+#' )
+#' 
+#' pairwise_aris <- subsample_pairwise_aris(
+#'     batch_subsample_results,
+#'     verbose = TRUE
+#' )
+#' 
+#' # Visualize ARIs 
+#' ComplexHeatmap::Heatmap(
+#'     pairwise_aris$"raw_aris"[[1]],
+#'     heatmap_legend_param = list(
+#'         color_bar = "continuous",
+#'         title = "Inter-Subsample\nARI",
+#'         at = c(0, 0.5, 1)
+#'     ),
+#'     show_column_names = FALSE,
+#'     show_row_names = FALSE
+#' )
+#' }
 subsample_pairwise_aris <- function(subsample_solutions,
                                     verbose = FALSE) {
     ###########################################################################
@@ -225,7 +234,7 @@ subsample_pairwise_aris <- function(subsample_solutions,
         )
     }
     ###########################################################################
-    # Skeleton to store the mean and sd of ARIs for each solution
+    # Skeleton to store the mean and SD of ARIs for each solution
     ###########################################################################
     pairwise_ari_df <- data.frame(
         "row" = integer(),
@@ -297,49 +306,52 @@ subsample_pairwise_aris <- function(subsample_solutions,
     return(results)
 }
 
-#' Density plot coclustering stability across subsampled data.
+#' Density plot of co-clustering stability across subsampled data
 #'
 #' This function creates a density plot that shows, for all pairs of
 #' observations that originally clustered together, the distribution of the
 #' the fractions that those pairs clustered together across subsampled data.
 #'
-#' @param cocluster_df A data frame containing coclustering data for a single
+#' @param cocluster_df A data frame containing co-clustering data for a single
 #'  cluster solution. This object is generated by the `calculate_coclustering`
 #'  function.
 #' @return Density plot (class "gg", "ggplot") of the distribution of
-#'  coclustering across pairs and subsamples of the data.
+#'  co-clustering across pairs and subsamples of the data.
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
-#' # 
-#' # sol_df <- batch_snf(my_dl, sc)
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
-#' # 
-#' # batch_subsample_results <- batch_snf_subsamples(
-#' #     my_dl_subsamples,
-#' #     sc,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # coclustering_results <- calculate_coclustering(
-#' #     batch_subsample_results,
-#' #     sol_df,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # cocluster_density(cocluster_dfs[[1]])
+#' \donttest{
+#' my_dl <- data_list(
+#'     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'     list(income, "household_income", "demographics", "continuous"),
+#'     list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'     uid = "unique_id"
+#' )
+#' 
+#' sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
+#' 
+#' sol_df <- batch_snf(my_dl, sc)
+#' 
+#' my_dl_subsamples <- subsample_dl(
+#'     my_dl,
+#'     n_subsamples = 20,
+#'     subsample_fraction = 0.85
+#' )
+#' 
+#' batch_subsample_results <- batch_snf_subsamples(
+#'     my_dl_subsamples,
+#'     sc
+#' )
+#'
+#' coclustering_results <- calculate_coclustering(
+#'     batch_subsample_results,
+#'     sol_df,
+#'     verbose = TRUE
+#' )
+#'
+#' cocluster_dfs <- coclustering_results$"cocluster_dfs"
+#'
+#' cocluster_density(cocluster_dfs[[1]])
+#' }
 cocluster_density <- function(cocluster_df) {
     ###########################################################################
     # dplyr warning handling
@@ -382,12 +394,12 @@ cocluster_density <- function(cocluster_df) {
     return(dist_plot)
 }
 
-#' Heatmap of observation co-clustering across resampled data.
+#' Heatmap of observation co-clustering across resampled data
 #'
 #' Create a heatmap that shows the distribution of observation co-clustering
 #' across resampled data.
 #'
-#' @param cocluster_df A data frame containing coclustering data for a single
+#' @param cocluster_df A data frame containing co-clustering data for a single
 #' cluster solution. This object is generated by the `calculate_coclustering`
 #' function.
 #'
@@ -413,57 +425,58 @@ cocluster_density <- function(cocluster_df) {
 #'  distribution of observation co-clustering across resampled data.
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
-#' # 
-#' # sol_df <- batch_snf(my_dl, sc)
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
-#' # 
-#' # batch_subsample_results <- batch_snf_subsamples(
-#' #     my_dl_subsamples,
-#' #     sc,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # coclustering_results <- calculate_coclustering(
-#' #     batch_subsample_results, 
-#' #     sol_df,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # cocluster_dfs <- coclustering_results$"cocluster_dfs"
-#' # 
-#' # cocluster_heatmap(
-#' #     cocluster_dfs[[1]],
-#' #     dl = my_dl,
-#' #     top_hm = list(
-#' #         "Income" = "household_income",
-#' #         "Pubertal Status" = "pubertal_status"
-#' #     ),
-#' #     annotation_colours = list(
-#' #         "Pubertal Status" = colour_scale(
-#' #             c(1, 4),
-#' #             min_colour = "black",
-#' #             max_colour = "purple"
-#' #         ),
-#' #         "Income" = colour_scale(
-#' #             c(0, 4),
-#' #             min_colour = "black",
-#' #             max_colour = "red"
-#' #         )
-#' #     )
-#' # )
+#' \donttest{
+#'     my_dl <- data_list(
+#'         list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'         list(income, "household_income", "demographics", "continuous"),
+#'         list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'         uid = "unique_id"
+#'     )
+#'     
+#'     sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
+#'     
+#'     sol_df <- batch_snf(my_dl, sc)
+#'     
+#'     my_dl_subsamples <- subsample_dl(
+#'         my_dl,
+#'         n_subsamples = 20,
+#'         subsample_fraction = 0.85
+#'     )
+#'     
+#'     batch_subsample_results <- batch_snf_subsamples(
+#'         my_dl_subsamples,
+#'         sc
+#'     )
+#'     
+#'     coclustering_results <- calculate_coclustering(
+#'         batch_subsample_results, 
+#'         sol_df,
+#'         verbose = TRUE
+#'     )
+#'     
+#'     cocluster_dfs <- coclustering_results$"cocluster_dfs"
+#'     
+#'     cocluster_heatmap(
+#'         cocluster_dfs[[1]],
+#'         dl = my_dl,
+#'         top_hm = list(
+#'             "Income" = "household_income",
+#'             "Pubertal Status" = "pubertal_status"
+#'         ),
+#'         annotation_colours = list(
+#'             "Pubertal Status" = colour_scale(
+#'                 c(1, 4),
+#'                 min_colour = "black",
+#'                 max_colour = "purple"
+#'             ),
+#'             "Income" = colour_scale(
+#'                 c(0, 4),
+#'                 min_colour = "black",
+#'                 max_colour = "red"
+#'             )
+#'         )
+#'     )
+#' }
 cocluster_heatmap <- function(cocluster_df,
                               cluster_rows = TRUE,
                               cluster_columns = TRUE,
@@ -536,7 +549,7 @@ cocluster_heatmap <- function(cocluster_df,
     diag(cocluster_mat) <- 1
     colnames(cocluster_mat) <- cluster_solution$"uid"
     rownames(cocluster_mat) <- cluster_solution$"uid"
-    # Loop through the coclustering data frame and populate the matrices
+    # Loop through the co-clustering data frame and populate the matrices
     for (i in seq_len(nrow(cocluster_df))) {
         row <- cocluster_df[i, ]
         s1 <- row$"obs_1"
@@ -597,7 +610,7 @@ cocluster_heatmap <- function(cocluster_df,
     return(heatmap)
 }
 
-#' Calculate coclustering data.
+#' Calculate co-clustering data
 #'
 #' @param subsample_solutions A list of containing cluster solutions from
 #' distinct subsamples of the data. This object is generated by the function
@@ -627,34 +640,35 @@ cocluster_heatmap <- function(cocluster_df,
 #' @importFrom data.table := setnames setkey as.data.table
 #' @export
 #' @examples
-#' # my_dl <- data_list(
-#' #     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
-#' #     list(income, "household_income", "demographics", "continuous"),
-#' #     list(pubertal, "pubertal_status", "demographics", "continuous"),
-#' #     uid = "unique_id"
-#' # )
-#' # 
-#' # sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
-#' # 
-#' # sol_df <- batch_snf(my_dl, sc)
-#' # 
-#' # my_dl_subsamples <- subsample_dl(
-#' #     my_dl,
-#' #     n_subsamples = 20,
-#' #     subsample_fraction = 0.85
-#' # )
-#' # 
-#' # batch_subsample_results <- batch_snf_subsamples(
-#' #     my_dl_subsamples,
-#' #     sc,
-#' #     verbose = TRUE
-#' # )
-#' # 
-#' # coclustering_results <- calculate_coclustering(
-#' #     batch_subsample_results,
-#' #     sol_df,
-#' #     verbose = TRUE
-#' # )
+#' \donttest{
+#'     my_dl <- data_list(
+#'         list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
+#'         list(income, "household_income", "demographics", "continuous"),
+#'         list(pubertal, "pubertal_status", "demographics", "continuous"),
+#'         uid = "unique_id"
+#'     )
+#'     
+#'     sc <- snf_config(my_dl, n_solutions = 5, max_k = 40)
+#'     
+#'     sol_df <- batch_snf(my_dl, sc)
+#'     
+#'     my_dl_subsamples <- subsample_dl(
+#'         my_dl,
+#'         n_subsamples = 20,
+#'         subsample_fraction = 0.85
+#'     )
+#'     
+#'     batch_subsample_results <- batch_snf_subsamples(
+#'         my_dl_subsamples,
+#'         sc
+#'     )
+#'     
+#'     coclustering_results <- calculate_coclustering(
+#'         batch_subsample_results,
+#'         sol_df,
+#'         verbose = TRUE
+#'     )
+#' }
 calculate_coclustering <- function(subsample_solutions,
                                    sol_df,
                                    verbose = FALSE) {
@@ -682,7 +696,7 @@ calculate_coclustering <- function(subsample_solutions,
     ###########################################################################
     # Data frame that will store summary data
     cocluster_frac_df <- data.frame()
-    # List that will optionally track raw coclustering data
+    # List that will optionally track raw co-clustering data
     cocluster_dfs <- list()
     cocluster_ss_mats <- list()
     cocluster_sc_mats <- list()
@@ -783,13 +797,13 @@ calculate_coclustering <- function(subsample_solutions,
     return(results)
 }
 
-#' Coclustering coverage check
+#' Co-clustering coverage check
 #'
-#' Check if coclustered data has at least one subsample in which every pair
+#' Check if co-clustered data has at least one subsample in which every pair
 #' of observations were a part of simultaneously.
 #'
 #' @keywords internal
-#' @param cocluster_df data frame containing coclustering data.
+#' @param cocluster_df data frame containing co-clustering data.
 #' @param action Control if parent function should warn or stop.
 #' @return This function does not return any value. It checks a `cocluster_df`
 #'  for complete coverage (all pairs occur in the same solution at least once).
