@@ -9,9 +9,6 @@ test_that("function and parallel equivalent run and give equal results", {
     library(metasnf)
     # Setting up the data
     dl <- data_list(
-        list(abcd_cort_t, "cort_thick", "neuroimaging", "continuous"),
-        list(abcd_cort_sa, "cort_sa", "neuroimaging", "continuous"),
-        list(abcd_subc_v, "subcortical_volume", "neuroimaging", "continuous"),
         list(abcd_income, "household_income", "demographics", "continuous"),
         list(abcd_pubertal, "pubertal_status", "demographics", "continuous"),
         uid = "patient"
@@ -20,7 +17,7 @@ test_that("function and parallel equivalent run and give equal results", {
     set.seed(42)
     config <- snf_config(
         dl,
-        n_solutions = 3,
+        n_solutions = 2,
         max_k = 40
     )
     # This matrix has clustering solutions for each of the 5 SNF runs!
